#
# spec file for package python-nodeenv
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15allpythons}
Name:           python-nodeenv
Version:        1.9.1
Release:        3.1
Summary:        Nodejs virtual environment builder
License:        BSD-3-Clause
URL:            https://github.com/ekalinin/nodeenv
Source:         https://github.com/ekalinin/nodeenv/archive/%{version}.tar.gz#/nodeenv-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Node.js virtual environment builder.

%prep
%autosetup -p1 -n nodeenv-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/nodeenv
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_smoke is an integration test requiring network access.
%pytest -k 'not test_smoke'

%post
%python_install_alternative nodeenv

%postun
%python_uninstall_alternative nodeenv

%files %{python_files}
%doc CHANGES README.rst
%license LICENSE
%python_alternative %{_bindir}/nodeenv
%{python_sitelib}/nodeenv.py
%pycache_only %{python_sitelib}/__pycache__/nodeenv.*.pyc
%{python_sitelib}/nodeenv-%{version}.dist-info

%changelog
* Mon May  5 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Wed Nov 13 2024 Daniel Garcia <daniel.garcia@suse.com>
- Fix package license to BSD-3-Clause
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- update to 1.9.1:
  * #358
  * #338
  * #347
  * #348
  * #345
  * #342
  * #346
* Wed Dec 20 2023 Dirk Müller <dmueller@suse.com>
- update to 1.8.0:
  * Changes:
  * #312
  * #313
  * #317
  * #320
  * #327
  * #329
  * #330
- drop python-nodeenv-no-mock.patch (obsolete)
* Thu Nov 23 2023 Matthias Bach <marix@marix.org>
- Also build for modern Python on Leap.
- Drop explicit definition of %%python_module in the spec file.
  This is nowadays defined on all distributions we build for.
* Tue Jul 19 2022 Dirk Müller <dmueller@suse.com>
- update to 1.7.0:
  * improved m1 support
  * drop python 3.4-3.6
* Thu Mar 24 2022 pgajdos@suse.com
- do not require pytest-mock for build
- added patches
  fix https://github.com/ekalinin/nodeenv/issues/302
  + python-nodeenv-no-mock.patch
* Thu Jun 17 2021 Dirk Müller <dmueller@suse.com>
- update to 1.6.0:
  * M1 support
* Wed Sep 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.5.0:
  * ignore ssl option, MSYS2 support
* Sun Jun 14 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.4.0:
  * a new way of the mirroring; some fixes
* Thu May 21 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Mar 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.3.5
* Tue Oct 22 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
* Thu Apr  4 2019 John Vandenberg <jayvdb@gmail.com>
- Add Python 3 with single spec
- Update to v1.3.3
* Fri Jan 13 2017 mardnh@gmx.de
- initial package, version 1.0.0
